<template>
  <div>
    <filter-table :meta="meta" @tingkat="handleTingkat" @rombel="handleRombel" @mapel="handleMapel"></filter-table>
    <b-row>
      <b-col md="4" class="mb-2">
        <v-select v-model="meta.per_page" :options="[10, 25, 50, 100]" @input="loadPerPage" :clearable="false">
          <template slot="no-options">
            Tidak ada data untuk ditampilkan
          </template>
        </v-select>
      </b-col>
      <b-col md="4" class="mb-2" offset-md="4">
        <b-form-input @input="search" placeholder="Cari data..."></b-form-input>
      </b-col>
    </b-row>
    <b-overlay :show="loading" rounded opacity="0.6" size="lg" spinner-variant="warning">
      <b-table responsive bordered striped :items="items" :fields="fields" :sort-by.sync="sortBy" :sort-desc.sync="sortDesc" show-empty :busy="isBusy">
        <template #table-busy>
          <div class="text-center text-danger my-2">
            <b-spinner class="align-middle"></b-spinner>
            <strong>Loading...</strong>
          </div>
        </template>
        <template v-slot:cell(mata_pelajaran_id)="row">
          {{row.item.mata_pelajaran.nama}}
        </template>
        <template v-slot:cell(kelas)="row">
          <span v-if="row.item.kelas_10">10</span>
          <span v-if="row.item.kelas_11">11</span>
          <span v-if="row.item.kelas_12">12</span>
          <span v-if="row.item.kelas_13">13</span>
        </template>
        <template v-slot:cell(kompetensi_dasar)="row">
          {{(row.item.kompetensi_dasar_alias) ? row.item.kompetensi_dasar_alias : row.item.kompetensi_dasar}}
        </template>
        <template v-slot:cell(status)="row">
          <b-badge variant="success" v-if="row.item.aktif">Aktif</b-badge>
          <b-badge variant="danger" v-else>Non Aktif</b-badge>
        </template>
        <template v-slot:cell(actions)="row">
          <b-dropdown id="dropdown-dropleft" dropleft text="Aksi" variant="success" size="sm">
            <b-dropdown-item href="javascript:" @click="edit(row.item)"><font-awesome-icon icon="fa-solid fa-pencil" /> Ubah Ringkasan</b-dropdown-item>
            <b-dropdown-item href="javascript:" @click="hapus(row.item.kompetensi_dasar_id)"><font-awesome-icon icon="fa-solid fa-trash" /> Hapus</b-dropdown-item>
            <b-dropdown-item href="javascript:" @click="nonAktifkan(row.item.kompetensi_dasar_id)" v-if="row.item.aktif"><font-awesome-icon icon="fa-solid fa-xmark" /> Non Aktifkan</b-dropdown-item>
            <b-dropdown-item href="javascript:" @click="aktifkan(row.item.kompetensi_dasar_id)" v-else><font-awesome-icon icon="fa-solid fa-check" /> Aktifkan</b-dropdown-item>
            <b-dropdown-item href="javascript:" @click="hapusGanda(row.item)"><font-awesome-icon icon="fa-solid fa-power-off" /> Hapus Data Ganda</b-dropdown-item>
          </b-dropdown>
        </template>
      </b-table>
    </b-overlay>
    <b-row class="mt-2">
      <b-col md="6">
        <p>Menampilkan {{ (meta.from) ? meta.from : 0 }} sampai {{ meta.to }} dari {{ meta.total }} entri</p>
      </b-col>
      <b-col md="6">
        <b-pagination v-model="meta.current_page" :total-rows="meta.total" :per-page="meta.per_page" align="right" @change="changePage" aria-controls="dw-datatable"></b-pagination>
      </b-col>
    </b-row>
  </div>
</template>

<script>
import _ from 'lodash' //IMPORT LODASH, DIMANA AKAN DIGUNAKAN UNTUK MEMBUAT DELAY KETIKA KOLOM PENCARIAN DIISI
import { BRow, BCol, BFormInput, BFormSelect, BTable, BSpinner, BPagination, BButton, BOverlay, BDropdown, BDropdownItem, BBadge } from 'bootstrap-vue'
import vSelect from 'vue-select'
import FilterTable from '@/views/components/FilterTable.vue'
export default {
  components: {
    vSelect,
    FilterTable,
    BRow,
    BCol,
    BFormInput, BFormSelect,
    BTable,
    BSpinner,
    BPagination,
    BButton,
    BOverlay,
    BDropdown, BDropdownItem, BBadge
  },
  props: {
    items: {
      type: Array,
      required: true
    },
    fields: {
      type: Array,
      required: true
    },
    meta: {
      required: true
    },
    isBusy: {
      type: Boolean,
      default: () => true,
    },
    loading: {
      type: Boolean,
      default: () => false,
    }
  },
  data() {
    return {
      sortBy: null,
      sortDesc: false,
    }
  },
  watch: {
    sortBy(val) {
      this.$emit('sort', {
        sortBy: this.sortBy,
        sortDesc: this.sortDesc
      })
    },
    sortDesc(val) {
      this.$emit('sort', {
        sortBy: this.sortBy,
        sortDesc: this.sortDesc
      })
    }
  },
  methods: {
    edit(val) {
      this.$emit('edit', val)
    },
    hapus(val) {
      this.$emit('hapus', val)
    },
    nonAktifkan(val) {
      this.$emit('nonAktifkan', val)
    },
    aktifkan(val) {
      this.$emit('aktifkan', val)
    },
    hapusGanda(val) {
      this.$emit('hapusGanda', val)
    },
    loadPerPage(val) {
      this.$emit('per_page', this.meta.per_page)
    },
    changePage(val) {
      this.$emit('pagination', val)
    },
    search: _.debounce(function (e) {
      this.$emit('search', e)
    }, 500),
    handleTingkat(val){
      this.$emit('tingkat', val)
    },
    handleRombel(val){
      this.$emit('rombel', val)
    },
    handleMapel(val){
      this.$emit('mapel', val)
    },
  },
}
</script>